summaryrefslogtreecommitdiffstats
path: root/src/kernel/qimage.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-02-28 22:31:39 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-02-28 22:31:39 -0600
commit41bb408dde90e755b07cd2ab8a9bdec7548c84b0 (patch)
tree6d4d5407c000add30aa78630e009c0e5d633e440 /src/kernel/qimage.cpp
parent1740cd279522c060e738bbbffacab83355d2b794 (diff)
downloadtqt3-41bb408dde90e755b07cd2ab8a9bdec7548c84b0.tar.gz
tqt3-41bb408dde90e755b07cd2ab8a9bdec7548c84b0.zip
Automated conversion from qt3
Diffstat (limited to 'src/kernel/qimage.cpp')
-rw-r--r--src/kernel/qimage.cpp84
1 files changed, 42 insertions, 42 deletions
diff --git a/src/kernel/qimage.cpp b/src/kernel/qimage.cpp
index bb7e1da93..c67c463ab 100644
--- a/src/kernel/qimage.cpp
+++ b/src/kernel/qimage.cpp
@@ -427,9 +427,9 @@ TQImage::TQImage( const char * const xpm[] )
#ifndef QT_NO_IMAGEIO_XPM
read_xpm_image_or_array( 0, xpm, *this );
#else
// We use a qFatal rather than disabling the whole function, as this
// constructor may be ambiguous.
- qFatal("XPM not supported");
+ tqFatal("XPM not supported");
#endif
}
@@ -588,7 +588,7 @@ TQImage TQImage::fromMimeSource( const TQString &abs_name )
const TQMimeSource *m = TQMimeSourceFactory::defaultFactory()->data( abs_name );
if ( !m ) {
#if defined(QT_CHECK_STATE)
- qWarning("TQImage::fromMimeSource: Cannot find image \"%s\" in the mime source factory", abs_name.latin1() );
+ tqWarning("TQImage::fromMimeSource: Cannot find image \"%s\" in the mime source factory", abs_name.latin1() );
#endif
return TQImage();
}
@@ -944,7 +944,7 @@ TQImage TQImage::copy(int x, int y, int w, int h, int conversion_flags) const
void TQImage::warningIndexRange( const char *func, int i )
{
#if defined(QT_CHECK_RANGE)
- qWarning( "TQImage::%s: Index %d out of range", func, i );
+ tqWarning( "TQImage::%s: Index %d out of range", func, i );
#else
Q_UNUSED( func )
Q_UNUSED( i )
@@ -1091,7 +1091,7 @@ TQImage::Endian TQImage::systemByteOrder()
if ( sbo == IgnoreEndian ) { // initialize
int ws;
bool be;
- qSysInfo( &ws, &be );
+ tqSysInfo( &ws, &be );
sbo = be ? BigEndian : LittleEndian;
}
return sbo;
@@ -1130,7 +1130,7 @@ TQImage::Endian TQImage::systemByteOrder()
TQImage::Endian TQImage::systemBitOrder()
{
#if defined(Q_WS_X11)
- return BitmapBitOrder(qt_xdisplay()) == MSBFirst ? BigEndian :LittleEndian;
+ return BitmapBitOrder(tqt_xdisplay()) == MSBFirst ? BigEndian :LittleEndian;
#else
return BigEndian;
#endif
@@ -1242,7 +1242,7 @@ bool TQImage::create( int width, int height, int depth, int numColors,
return FALSE; // invalid parameter(s)
if ( depth == 1 && bitOrder == IgnoreEndian ) {
#if defined(QT_CHECK_RANGE)
- qWarning( "TQImage::create: Bit order is required for 1 bpp images" );
+ tqWarning( "TQImage::create: Bit order is required for 1 bpp images" );
#endif
return FALSE;
}
@@ -1251,7 +1251,7 @@ bool TQImage::create( int width, int height, int depth, int numColors,
#if defined(QT_CHECK_RANGE)
if ( depth == 24 )
- qWarning( "TQImage::create: 24-bpp images no longer supported, "
+ tqWarning( "TQImage::create: 24-bpp images no longer supported, "
"use 32-bpp instead" );
#endif
switch ( depth ) {
@@ -2162,9 +2162,9 @@ TQImage TQImage::convertDepth( int depth, int conversion_flags ) const
else {
#if defined(QT_CHECK_RANGE)
if ( isNull() )
- qWarning( "TQImage::convertDepth: Image is a null image" );
+ tqWarning( "TQImage::convertDepth: Image is a null image" );
else
- qWarning( "TQImage::convertDepth: Depth %d not supported", depth );
+ tqWarning( "TQImage::convertDepth: Depth %d not supported", depth );
#endif
}
return image;
@@ -2206,7 +2206,7 @@ int TQImage::pixelIndex( int x, int y ) const
{
#if defined(QT_CHECK_RANGE)
if ( x < 0 || x >= width() ) {
- qWarning( "TQImage::pixel: x=%d out of range", x );
+ tqWarning( "TQImage::pixel: x=%d out of range", x );
return -12345;
}
#endif
@@ -2225,7 +2225,7 @@ int TQImage::pixelIndex( int x, int y ) const
#endif
case 32:
#if defined(QT_CHECK_RANGE)
- qWarning( "TQImage::pixelIndex: Not applicable for %d-bpp images "
+ tqWarning( "TQImage::pixelIndex: Not applicable for %d-bpp images "
"(no palette)", depth() );
#endif
return 0;
@@ -2248,7 +2248,7 @@ TQRgb TQImage::pixel( int x, int y ) const
{
#if defined(QT_CHECK_RANGE)
if ( x < 0 || x >= width() ) {
- qWarning( "TQImage::pixel: x=%d out of range", x );
+ tqWarning( "TQImage::pixel: x=%d out of range", x );
return 12345;
}
#endif
@@ -2292,7 +2292,7 @@ void TQImage::setPixel( int x, int y, uint index_or_rgb )
{
if ( x < 0 || x >= width() ) {
#if defined(QT_CHECK_RANGE)
- qWarning( "TQImage::setPixel: x=%d out of range", x );
+ tqWarning( "TQImage::setPixel: x=%d out of range", x );
#endif
return;
}
@@ -2300,7 +2300,7 @@ void TQImage::setPixel( int x, int y, uint index_or_rgb )
uchar * s = scanLine( y );
if ( index_or_rgb > 1) {
#if defined(QT_CHECK_RANGE)
- qWarning( "TQImage::setPixel: index=%d out of range",
+ tqWarning( "TQImage::setPixel: index=%d out of range",
index_or_rgb );
#endif
} else if ( bitOrder() == TQImage::LittleEndian ) {
@@ -2317,7 +2317,7 @@ void TQImage::setPixel( int x, int y, uint index_or_rgb )
} else if ( depth() == 8 ) {
if (index_or_rgb > (uint)numColors()) {
#if defined(QT_CHECK_RANGE)
- qWarning( "TQImage::setPixel: index=%d out of range",
+ tqWarning( "TQImage::setPixel: index=%d out of range",
index_or_rgb );
#endif
return;
@@ -2789,7 +2789,7 @@ TQImage TQImage::smoothScale( const TQSize& s, ScaleMode mode ) const
{
if ( isNull() ) {
#if defined(QT_CHECK_RANGE)
- qWarning( "TQImage::smoothScale: Image is a null image" );
+ tqWarning( "TQImage::smoothScale: Image is a null image" );
#endif
return copy();
}
@@ -2854,7 +2854,7 @@ TQImage TQImage::scale( const TQSize& s, ScaleMode mode ) const
{
if ( isNull() ) {
#if defined(QT_CHECK_RANGE)
- qWarning( "TQImage::scale: Image is a null image" );
+ tqWarning( "TQImage::scale: Image is a null image" );
#endif
return copy();
}
@@ -2892,7 +2892,7 @@ TQImage TQImage::scaleWidth( int w ) const
{
if ( isNull() ) {
#if defined(QT_CHECK_RANGE)
- qWarning( "TQImage::scaleWidth: Image is a null image" );
+ tqWarning( "TQImage::scaleWidth: Image is a null image" );
#endif
return copy();
}
@@ -2921,7 +2921,7 @@ TQImage TQImage::scaleHeight( int h ) const
{
if ( isNull() ) {
#if defined(QT_CHECK_RANGE)
- qWarning( "TQImage::scaleHeight: Image is a null image" );
+ tqWarning( "TQImage::scaleHeight: Image is a null image" );
#endif
return copy();
}
@@ -3336,7 +3336,7 @@ TQImage TQImage::swapRGB() const
}
#ifndef QT_NO_IMAGE_16_BIT
} else if ( depth() == 16 ) {
- qWarning( "TQImage::swapRGB not implemented for 16bpp" );
+ tqWarning( "TQImage::swapRGB not implemented for 16bpp" );
#endif
} else
#endif //QT_NO_IMAGE_TRUECOLOR
@@ -3562,7 +3562,7 @@ bool TQImage::doImageIO( TQImageIO* io, int quality ) const
io->setImage( *this );
#if defined(QT_CHECK_RANGE)
if ( quality > 100 || quality < -1 )
- qWarning( "TQPixmap::save: quality out of range [-1,100]" );
+ tqWarning( "TQPixmap::save: quality out of range [-1,100]" );
#endif
if ( quality >= 0 )
io->setQuality( TQMIN(quality,100) );
@@ -3899,7 +3899,7 @@ void qt_init_image_handlers() // initialize image handlers
imageHandlers = new TQIHList;
TQ_CHECK_PTR( imageHandlers );
imageHandlers->setAutoDelete( TRUE );
- qAddPostRoutine( cleanup );
+ tqAddPostRoutine( cleanup );
#ifndef QT_NO_IMAGEIO_BMP
TQImageIO::defineIOHandler( "BMP", "^BM", 0,
read_bmp_image, write_bmp_image );
@@ -4199,7 +4199,7 @@ void TQImageIO::setParameters( const char *parameters )
{
if ( d && d->parameters )
delete [] (char*)d->parameters;
- d->parameters = qstrdup( parameters );
+ d->parameters = tqstrdup( parameters );
}
/*!
@@ -4502,7 +4502,7 @@ bool TQImageIO::write()
}
if ( !h || !h->write_image ) {
#if defined(QT_CHECK_RANGE)
- qWarning( "TQImageIO::write: No such image format handler: %s",
+ tqWarning( "TQImageIO::write: No such image format handler: %s",
format() );
#endif
return FALSE;
@@ -4637,19 +4637,19 @@ bool read_dib( TQDataStream& s, int offset, int startpos, TQImage& image )
if ( d->atEnd() ) // end of stream/file
return FALSE;
#if 0
- qDebug( "offset...........%d", offset );
- qDebug( "startpos.........%d", startpos );
- qDebug( "biSize...........%d", bi.biSize );
- qDebug( "biWidth..........%d", bi.biWidth );
- qDebug( "biHeight.........%d", bi.biHeight );
- qDebug( "biPlanes.........%d", bi.biPlanes );
- qDebug( "biBitCount.......%d", bi.biBitCount );
- qDebug( "biCompression....%d", bi.biCompression );
- qDebug( "biSizeImage......%d", bi.biSizeImage );
- qDebug( "biXPelsPerMeter..%d", bi.biXPelsPerMeter );
- qDebug( "biYPelsPerMeter..%d", bi.biYPelsPerMeter );
- qDebug( "biClrUsed........%d", bi.biClrUsed );
- qDebug( "biClrImportant...%d", bi.biClrImportant );
+ tqDebug( "offset...........%d", offset );
+ tqDebug( "startpos.........%d", startpos );
+ tqDebug( "biSize...........%d", bi.biSize );
+ tqDebug( "biWidth..........%d", bi.biWidth );
+ tqDebug( "biHeight.........%d", bi.biHeight );
+ tqDebug( "biPlanes.........%d", bi.biPlanes );
+ tqDebug( "biBitCount.......%d", bi.biBitCount );
+ tqDebug( "biCompression....%d", bi.biCompression );
+ tqDebug( "biSizeImage......%d", bi.biSizeImage );
+ tqDebug( "biXPelsPerMeter..%d", bi.biXPelsPerMeter );
+ tqDebug( "biYPelsPerMeter..%d", bi.biYPelsPerMeter );
+ tqDebug( "biClrUsed........%d", bi.biClrUsed );
+ tqDebug( "biClrImportant...%d", bi.biClrImportant );
#endif
int w = bi.biWidth, h = bi.biHeight, nbits = bi.biBitCount;
int t = bi.biSize, comp = bi.biCompression;
@@ -5758,7 +5758,7 @@ static void read_xpm_image_or_array( TQImageIO * iio, const char * const * sourc
for( currentColor=0; currentColor < ncols; ++currentColor ) {
if ( !read_xpm_string( buf, d, source, index ) ) {
#if defined(QT_CHECK_RANGE)
- qWarning( "TQImage: XPM color specification missing");
+ tqWarning( "TQImage: XPM color specification missing");
#endif
return;
}
@@ -5769,7 +5769,7 @@ static void read_xpm_image_or_array( TQImageIO * iio, const char * const * sourc
i = nextColorSpec(buf);
if ( i < 0 ) {
#if defined(QT_CHECK_RANGE)
- qWarning( "TQImage: XPM color specification is missing: %s", buf.data());
+ tqWarning( "TQImage: XPM color specification is missing: %s", buf.data());
#endif
return; // no c/g/g4/m/s specification at all
}
@@ -5809,7 +5809,7 @@ static void read_xpm_image_or_array( TQImageIO * iio, const char * const * sourc
for( int y=0; y<h; y++ ) {
if ( !read_xpm_string( buf, d, source, index ) ) {
#if defined(QT_CHECK_RANGE)
- qWarning( "TQImage: XPM pixels missing on image line %d", y);
+ tqWarning( "TQImage: XPM pixels missing on image line %d", y);
#endif
return;
}
@@ -6478,7 +6478,7 @@ TQGfx * TQImage::graphicsContext()
int h = qt_screen->mapToDevice( TQSize(width(),height()) ).height();
ret=TQGfx::createGfx(depth(),bits(),w,h,bytesPerLine());
} else {
- qDebug("Trying to create image for null depth");
+ tqDebug("Trying to create image for null depth");
return 0;
}
if(depth()<=8) {
@@ -427,9 +427,9 @@ TQImage::TQImage( const char * const xpm[] )
read_xpm_image_or_array( 0, xpm, *this );
#else
- // We use a qFatal rather than disabling the whole function, as this
+ // We use a tqFatal rather than disabling the whole function, as this
// constructor may be ambiguous.